@@ -13,12 +13,11 @@ import logging
 
 import maya.cmds as cmds
 import maya.mel as mel
-import maya.OpenMaya as OpenMaya
 
 import artella
 from artella import dcc
 from artella.core.dcc import callback
-from artella.core import consts, callbacks, plugins, dccplugin
+from artella.core import consts, callbacks, plugins, dccplugin, utils
 from artella.dccs.maya import utils as maya_utils
 
 logger = logging.getLogger('artella')
@@ -181,7 +180,7 @@ class ArtellaMayaPlugin(dccplugin.BaseArtellaDccPlugin):
 
         self.update_paths(show_dialogs=False, skip_save=True)
 
-    def _before_open_check(self, retcode, maya_file, client_data=None):
+    def _before_open_check(self, maya_file, client_data=None):
         """
         Internal callback function that is called before a Maya scene is opened
 
@@ -190,7 +189,7 @@ class ArtellaMayaPlugin(dccplugin.BaseArtellaDccPlugin):
         :param dict client_data:
         """
 
-        file_path = maya_file.resolvedFullName()
+        file_path = utils.clean_path(maya_file.resolvedFullName())
 
         if self.is_artella_path(file_path):
 
@@ -206,7 +205,7 @@ class ArtellaMayaPlugin(dccplugin.BaseArtellaDccPlugin):
             else:
                 get_deps_plugin.get_non_available_dependencies(file_path)
 
-        OpenMaya.MScriptUtil.setBool(retcode, True)
+        return True
 
     def _after_load_reference(self, *args):
         """
@@ -220,7 +219,7 @@ class ArtellaMayaPlugin(dccplugin.BaseArtellaDccPlugin):
 
         self.validate_environment_for_callback('AfterLoadReference')
 
-    def _before_reference_check(self, retcode, maya_file, client_data=None):
+    def _before_reference_check(self, maya_file, client_data=None):
         """
         Internal callback function that is called before a Maya reference is opened
 
@@ -238,4 +237,4 @@ class ArtellaMayaPlugin(dccplugin.BaseArtellaDccPlugin):
                 convert_path = dccplugin.DccPlugin().convert_path(raw_full_name)
                 maya_file.setRawFullName(convert_path)
 
-        OpenMaya.MScriptUtil.setBool(retcode, True)
+        return True
